import click

from utils.pandas_utils import message


@click.group()
@click.version_option(prog_name='Cloud Pipeline CLI')
def cli():
    """pipe is command line interface to Bfx Pipeline engine
    It allows run pipelines as well as viewing runs and cluster state
    """
    pass


@cli.command()
@click.option('-n', '--name',
              help='Red panda name',
              default='Yo')
def print_message(name):
    """Configures CLI parameters
    """
    print "Aloha pussies!"
    message(name)



from setuptools import setup, find_packages

setup(
    python_requires='<3.0.*',
    name='red-pandas',
    version='0.6',
    py_modules=['red_pandas'],
    description='A random test lib',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'click',
    ],
    entry_points='''
        [console_scripts]
        red-pandas=red_pandas:print_message
    ''',
)
